==> daal_include-2018.0.0.20170814-py2.py3-none-macosx_10_12_intel.macosx_10_12_x86_64.whl: daal_include-2018.0.0.20170814.data/data/include/algorithms/linear_model/linear_model_training_batch.h <==
/* file: linear_model_training_batch.h */
/*******************************************************************************
* Copyright 2014-2017 Intel Corporation
* All Rights Reserved.
*
* If this  software was obtained  under the  Intel Simplified  Software License,
* the following terms apply:
*
* The source code,  information  and material  ("Material") contained  herein is
* owned by Intel Corporation or its  suppliers or licensors,  and  title to such
* Material remains with Intel  Corporation or its  suppliers or  licensors.  The
* Material  contains  proprietary  information  of  Intel or  its suppliers  and
* licensors.  The Material is protected by  worldwide copyright  laws and treaty
* provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
* modified, published,  uploaded, posted, transmitted,  distributed or disclosed
* in any way without Intel's prior express written permission.  No license under
* any patent,  copyright or other  intellectual property rights  in the Material
* is granted to  or  conferred  upon  you,  either   expressly,  by implication,
* inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
* property rights must be express and approved by Intel in writing.
*
* Unless otherwise agreed by Intel in writing,  you may not remove or alter this
* notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
* suppliers or licensors in any way.
*
*
* If this  software  was obtained  under the  Apache License,  Version  2.0 (the
* "License"), the following terms apply:
*
* You may  not use this  file except  in compliance  with  the License.  You may
* obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
*
*
* Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
* distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
* WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*
* See the   License  for the   specific  language   governing   permissions  and
* limitations under the License.
*******************************************************************************/

/*
//++
//  Implementation of the interface for the regression model-based training
//  in the batch processing mode
//--
*/

#ifndef __LINEAR_MODEL_TRAINING_BATCH_H__
#define __LINEAR_MODEL_TRAINING_BATCH_H__

#include "algorithms/linear_model/linear_model_training_types.h"
#include "algorithms/regression/regression_training_batch.h"

namespace daal
{
namespace algorithms
{
namespace linear_model
{
namespace training
{
namespace interface1
{
/**
 * @defgroup linear_model_training_batch Batch
 * @ingroup linear_model_training
 * @{
 */
/**
 * <a name="DAAL-CLASS-ALGORITHMS__LINEAR_MODEL__TRAINING__BATCH"></a>
 * \brief Provides methods for linear model model-based training in the batch processing mode
 *
 * \par References
 *      - \ref linear_model::interface1::Model "linear_model::Model" class
 *      - \ref prediction::interface1::Batch "prediction::Batch" class
 */
class DAAL_EXPORT Batch : public regression::training::Batch
{
public:
    /**
     * Returns the structure that contains the result of linear model model-based training
     * \return Structure that contains the result of linear model model-based training
     */
    ResultPtr getResult() { return Result::cast(_result); }
};
/** @} */
}
using interface1::Batch;
}
}
}
}
#endif

==> daal_include-2019.0-py2.py3-none-macosx_10_12_intel.macosx_10_12_x86_64.whl: daal_include-2019.0.data/data/include/algorithms/linear_model/linear_model_training_batch.h <==
/* file: linear_model_training_batch.h */
/*******************************************************************************
* Copyright 2014-2018 Intel Corporation.
*
* This software and the related documents are Intel copyrighted  materials,  and
* your use of  them is  governed by the  express license  under which  they were
* provided to you (License).  Unless the License provides otherwise, you may not
* use, modify, copy, publish, distribute,  disclose or transmit this software or
* the related documents without Intel's prior written permission.
*
* This software and the related documents  are provided as  is,  with no express
* or implied  warranties,  other  than those  that are  expressly stated  in the
* License.
*******************************************************************************/

/*
//++
//  Implementation of the interface for the regression model-based training
//  in the batch processing mode
//--
*/

#ifndef __LINEAR_MODEL_TRAINING_BATCH_H__
#define __LINEAR_MODEL_TRAINING_BATCH_H__

#include "algorithms/linear_model/linear_model_training_types.h"
#include "algorithms/regression/regression_training_batch.h"

namespace daal
{
namespace algorithms
{
namespace linear_model
{
namespace training
{
namespace interface1
{
/**
 * @defgroup linear_model_training_batch Batch
 * @ingroup linear_model_training
 * @{
 */
/**
 * <a name="DAAL-CLASS-ALGORITHMS__LINEAR_MODEL__TRAINING__BATCH"></a>
 * \brief Provides methods for linear model model-based training in the batch processing mode
 *
 * \par References
 *      - \ref linear_model::interface1::Model "linear_model::Model" class
 *      - \ref prediction::interface1::Batch "prediction::Batch" class
 */
class DAAL_EXPORT Batch : public regression::training::Batch
{
public:
    typedef algorithms::linear_model::training::Input  InputType;
    typedef algorithms::linear_model::Parameter        ParameterType;
    typedef algorithms::linear_model::training::Result ResultType;

    /**
     * Returns the structure that contains the result of linear model model-based training
     * \return Structure that contains the result of linear model model-based training
     */
    ResultPtr getResult() { return ResultType::cast(_result); }
};
/** @} */
}
using interface1::Batch;
}
}
}
}
#endif
